from __future__ import annotations

import flatbuffers
import numpy as np

import flatbuffers
import typing

uoffset: typing.TypeAlias = flatbuffers.number_types.UOffsetTFlags.py_type

class Aggregation(object):
  none: int
  minimum: int
  maximum: int
  mean: int
  p10: int
  p25: int
  median: int
  p75: int
  p90: int
  dominant: int
  sum: int
  spread: int




from __future__ import annotations

import flatbuffers
import numpy as np

import flatbuffers
import typing
from openmeteo_sdk.VariableWithValues import VariableWithValues

uoffset: typing.TypeAlias = flatbuffers.number_types.UOffsetTFlags.py_type

class VariablesWithTime(object):
  @classmethod
  def GetRootAs(cls, buf: bytes, offset: int) -> VariablesWithTime: ...
  @classmethod
  def GetRootAsVariablesWithTime(cls, buf: bytes, offset: int) -> VariablesWithTime: ...
  def Init(self, buf: bytes, pos: int) -> None: ...
  def Time(self) -> int: ...
  def TimeEnd(self) -> int: ...
  def Interval(self) -> int: ...
  def Variables(self, i: int) -> VariableWithValues | None: ...
  def VariablesLength(self) -> int: ...
  def VariablesIsNone(self) -> bool: ...
def VariablesWithTimeStart(builder: flatbuffers.Builder) -> None: ...
def Start(builder: flatbuffers.Builder) -> None: ...
def VariablesWithTimeAddTime(builder: flatbuffers.Builder, time: int) -> None: ...
def VariablesWithTimeAddTimeEnd(builder: flatbuffers.Builder, timeEnd: int) -> None: ...
def VariablesWithTimeAddInterval(builder: flatbuffers.Builder, interval: int) -> None: ...
def VariablesWithTimeAddVariables(builder: flatbuffers.Builder, variables: uoffset) -> None: ...
def VariablesWithTimeStartVariablesVector(builder: flatbuffers.Builder, num_elems: int) -> uoffset: ...
def StartVariablesVector(builder: flatbuffers.Builder, num_elems: int) -> uoffset: ...
def VariablesWithTimeEnd(builder: flatbuffers.Builder) -> uoffset: ...
def End(builder: flatbuffers.Builder) -> uoffset: ...




# automatically generated by the FlatBuffers compiler, do not modify

# namespace: openmeteo_sdk

class Model(object):
    undefined = 0
    best_match = 1
    gfs_seamless = 2
    gfs_global = 3
    gfs_hrrr = 4
    meteofrance_seamless = 5
    meteofrance_arpege_seamless = 6
    meteofrance_arpege_world = 7
    meteofrance_arpege_europe = 8
    meteofrance_arome_seamless = 9
    meteofrance_arome_france = 10
    meteofrance_arome_france_hd = 11
    jma_seamless = 12
    jma_msm = 13
    jms_gsm = 14
    jma_gsm = 15
    gem_seamless = 16
    gem_global = 17
    gem_regional = 18
    gem_hrdps_continental = 19
    icon_seamless = 20
    icon_global = 21
    icon_eu = 22
    icon_d2 = 23
    ecmwf_ifs04 = 24
    metno_nordic = 25
    era5_seamless = 26
    era5 = 27
    cerra = 28
    era5_land = 29
    ecmwf_ifs = 30
    gwam = 31
    ewam = 32
    glofas_seamless_v3 = 33
    glofas_forecast_v3 = 34
    glofas_consolidated_v3 = 35
    glofas_seamless_v4 = 36
    glofas_forecast_v4 = 37
    glofas_consolidated_v4 = 38
    gfs025 = 39
    gfs05 = 40
    CMCC_CM2_VHR4 = 41
    FGOALS_f3_H_highresSST = 42
    FGOALS_f3_H = 43
    HiRAM_SIT_HR = 44
    MRI_AGCM3_2_S = 45
    EC_Earth3P_HR = 46
    MPI_ESM1_2_XR = 47
    NICAM16_8S = 48
    cams_europe = 49
    cams_global = 50
    cfsv2 = 51
    era5_ocean = 52
    cma_grapes_global = 53
    bom_access_global = 54
    bom_access_global_ensemble = 55
    arpae_cosmo_seamless = 56
    arpae_cosmo_2i = 57
    arpae_cosmo_2i_ruc = 58
    arpae_cosmo_5m = 59
    ecmwf_ifs025 = 60
    ecmwf_aifs025 = 61
    gfs013 = 62
    gfs_graphcast025 = 63
    ecmwf_wam025 = 64
    meteofrance_wave = 65
    meteofrance_currents = 66
    ecmwf_wam025_ensemble = 67
    ncep_gfswave025 = 68
    ncep_gefswave025 = 69
    knmi_seamless = 70
    knmi_harmonie_arome_europe = 71
    knmi_harmonie_arome_netherlands = 72
    dmi_seamless = 73
    dmi_harmonie_arome_europe = 74
    metno_seamless = 75
    era5_ensemble = 76
    ecmwf_ifs_analysis = 77
    ecmwf_ifs_long_window = 78
    ecmwf_ifs_analysis_long_window = 79
    ukmo_global_deterministic_10km = 80
    ukmo_uk_deterministic_2km = 81
    ukmo_seamless = 82
    ncep_gfswave016 = 83
    ncep_nbm_conus = 84
    ukmo_global_ensemble_20km = 85
    ecmwf_aifs025_single = 86
    jma_jaxa_himawari = 87
    eumetsat_sarah3 = 88
    eumetsat_lsa_saf_msg = 89
    eumetsat_lsa_saf_iodc = 90
    satellite_radiation_seamless = 91
    kma_gdps = 92
    kma_ldps = 93
    kma_seamless = 94
    italia_meteo_arpae_icon_2i = 95



from __future__ import annotations

import flatbuffers
import numpy as np

import flatbuffers
import typing

uoffset: typing.TypeAlias = flatbuffers.number_types.UOffsetTFlags.py_type

class Variable(object):
  undefined: int
  apparent_temperature: int
  cape: int
  cloud_cover: int
  cloud_cover_high: int
  cloud_cover_low: int
  cloud_cover_mid: int
  daylight_duration: int
  dew_point: int
  diffuse_radiation: int
  diffuse_radiation_instant: int
  direct_normal_irradiance: int
  direct_normal_irradiance_instant: int
  direct_radiation: int
  direct_radiation_instant: int
  et0_fao_evapotranspiration: int
  evapotranspiration: int
  freezing_level_height: int
  growing_degree_days: int
  is_day: int
  latent_heat_flux: int
  leaf_wetness_probability: int
  lifted_index: int
  lightning_potential: int
  precipitation: int
  precipitation_hours: int
  precipitation_probability: int
  pressure_msl: int
  rain: int
  relative_humidity: int
  runoff: int
  sensible_heat_flux: int
  shortwave_radiation: int
  shortwave_radiation_instant: int
  showers: int
  snow_depth: int
  snow_height: int
  snowfall: int
  snowfall_height: int
  snowfall_water_equivalent: int
  sunrise: int
  sunset: int
  soil_moisture: int
  soil_moisture_index: int
  soil_temperature: int
  surface_pressure: int
  surface_temperature: int
  temperature: int
  terrestrial_radiation: int
  terrestrial_radiation_instant: int
  total_column_integrated_water_vapour: int
  updraft: int
  uv_index: int
  uv_index_clear_sky: int
  vapour_pressure_deficit: int
  visibility: int
  weather_code: int
  wind_direction: int
  wind_gusts: int
  wind_speed: int
  vertical_velocity: int
  geopotential_height: int
  wet_bulb_temperature: int
  river_discharge: int
  wave_height: int
  wave_period: int
  wave_direction: int
  wind_wave_height: int
  wind_wave_period: int
  wind_wave_peak_period: int
  wind_wave_direction: int
  swell_wave_height: int
  swell_wave_period: int
  swell_wave_peak_period: int
  swell_wave_direction: int
  pm10: int
  pm2p5: int
  dust: int
  aerosol_optical_depth: int
  carbon_monoxide: int
  nitrogen_dioxide: int
  ammonia: int
  ozone: int
  sulphur_dioxide: int
  alder_pollen: int
  birch_pollen: int
  grass_pollen: int
  mugwort_pollen: int
  olive_pollen: int
  ragweed_pollen: int
  european_aqi: int
  european_aqi_pm2p5: int
  european_aqi_pm10: int
  european_aqi_nitrogen_dioxide: int
  european_aqi_ozone: int
  european_aqi_sulphur_dioxide: int
  us_aqi: int
  us_aqi_pm2p5: int
  us_aqi_pm10: int
  us_aqi_nitrogen_dioxide: int
  us_aqi_ozone: int
  us_aqi_sulphur_dioxide: int
  us_aqi_carbon_monoxide: int
  sunshine_duration: int
  convective_inhibition: int
  shortwave_radiation_clear_sky: int
  global_tilted_irradiance: int
  global_tilted_irradiance_instant: int
  ocean_current_velocity: int
  ocean_current_direction: int
  cloud_base: int
  cloud_top: int
  mass_density: int
  boundary_layer_height: int
  formaldehyde: int
  glyoxal: int
  non_methane_volatile_organic_compounds: int
  pm10_wildfires: int
  peroxyacyl_nitrates: int
  secondary_inorganic_aerosol: int
  residential_elementary_carbon: int
  total_elementary_carbon: int
  pm2_5_total_organic_matter: int
  sea_salt_aerosol: int
  nitrogen_monoxide: int
  thunderstorm_probability: int
  rain_probability: int
  freezing_rain_probability: int
  ice_pellets_probability: int
  snowfall_probability: int
  carbon_dioxide: int
  methane: int
  sea_level_height_msl: int
  sea_surface_temperature: int
  invert_barometer_height: int
  hail: int
  albedo: int
  precipitation_type: int
  convective_cloud_base: int
  convective_cloud_top: int
  snow_depth_water_equivalent: int
  secondary_swell_wave_height: int
  secondary_swell_wave_period: int
  secondary_swell_wave_peak_period: int
  secondary_swell_wave_direction: int
  tertiary_swell_wave_height: int
  tertiary_swell_wave_period: int
  tertiary_swell_wave_peak_period: int
  tertiary_swell_wave_direction: int




from __future__ import annotations

import flatbuffers
import numpy as np

import flatbuffers
import typing

uoffset: typing.TypeAlias = flatbuffers.number_types.UOffsetTFlags.py_type

class Model(object):
  undefined: int
  best_match: int
  gfs_seamless: int
  gfs_global: int
  gfs_hrrr: int
  meteofrance_seamless: int
  meteofrance_arpege_seamless: int
  meteofrance_arpege_world: int
  meteofrance_arpege_europe: int
  meteofrance_arome_seamless: int
  meteofrance_arome_france: int
  meteofrance_arome_france_hd: int
  jma_seamless: int
  jma_msm: int
  jms_gsm: int
  jma_gsm: int
  gem_seamless: int
  gem_global: int
  gem_regional: int
  gem_hrdps_continental: int
  icon_seamless: int
  icon_global: int
  icon_eu: int
  icon_d2: int
  ecmwf_ifs04: int
  metno_nordic: int
  era5_seamless: int
  era5: int
  cerra: int
  era5_land: int
  ecmwf_ifs: int
  gwam: int
  ewam: int
  glofas_seamless_v3: int
  glofas_forecast_v3: int
  glofas_consolidated_v3: int
  glofas_seamless_v4: int
  glofas_forecast_v4: int
  glofas_consolidated_v4: int
  gfs025: int
  gfs05: int
  CMCC_CM2_VHR4: int
  FGOALS_f3_H_highresSST: int
  FGOALS_f3_H: int
  HiRAM_SIT_HR: int
  MRI_AGCM3_2_S: int
  EC_Earth3P_HR: int
  MPI_ESM1_2_XR: int
  NICAM16_8S: int
  cams_europe: int
  cams_global: int
  cfsv2: int
  era5_ocean: int
  cma_grapes_global: int
  bom_access_global: int
  bom_access_global_ensemble: int
  arpae_cosmo_seamless: int
  arpae_cosmo_2i: int
  arpae_cosmo_2i_ruc: int
  arpae_cosmo_5m: int
  ecmwf_ifs025: int
  ecmwf_aifs025: int
  gfs013: int
  gfs_graphcast025: int
  ecmwf_wam025: int
  meteofrance_wave: int
  meteofrance_currents: int
  ecmwf_wam025_ensemble: int
  ncep_gfswave025: int
  ncep_gefswave025: int
  knmi_seamless: int
  knmi_harmonie_arome_europe: int
  knmi_harmonie_arome_netherlands: int
  dmi_seamless: int
  dmi_harmonie_arome_europe: int
  metno_seamless: int
  era5_ensemble: int
  ecmwf_ifs_analysis: int
  ecmwf_ifs_long_window: int
  ecmwf_ifs_analysis_long_window: int
  ukmo_global_deterministic_10km: int
  ukmo_uk_deterministic_2km: int
  ukmo_seamless: int
  ncep_gfswave016: int
  ncep_nbm_conus: int
  ukmo_global_ensemble_20km: int
  ecmwf_aifs025_single: int
  jma_jaxa_himawari: int
  eumetsat_sarah3: int
  eumetsat_lsa_saf_msg: int
  eumetsat_lsa_saf_iodc: int
  satellite_radiation_seamless: int
  kma_gdps: int
  kma_ldps: int
  kma_seamless: int
  italia_meteo_arpae_icon_2i: int




# automatically generated by the FlatBuffers compiler, do not modify

# namespace: openmeteo_sdk

import flatbuffers
from flatbuffers.compat import import_numpy
from typing import Any
from openmeteo_sdk.VariableWithValues import VariableWithValues
from typing import Optional
np = import_numpy()

class VariablesWithTime(object):
    __slots__ = ['_tab']

    @classmethod
    def GetRootAs(cls, buf, offset: int = 0):
        n = flatbuffers.encode.Get(flatbuffers.packer.uoffset, buf, offset)
        x = VariablesWithTime()
        x.Init(buf, n + offset)
        return x

    @classmethod
    def GetRootAsVariablesWithTime(cls, buf, offset=0):
        """This method is deprecated. Please switch to GetRootAs."""
        return cls.GetRootAs(buf, offset)
    # VariablesWithTime
    def Init(self, buf: bytes, pos: int):
        self._tab = flatbuffers.table.Table(buf, pos)

    # VariablesWithTime
    def Time(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(4))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Int64Flags, o + self._tab.Pos)
        return 0

    # VariablesWithTime
    def TimeEnd(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(6))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Int64Flags, o + self._tab.Pos)
        return 0

    # VariablesWithTime
    def Interval(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(8))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Int32Flags, o + self._tab.Pos)
        return 0

    # VariablesWithTime
    def Variables(self, j: int) -> Optional[VariableWithValues]:
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(10))
        if o != 0:
            x = self._tab.Vector(o)
            x += flatbuffers.number_types.UOffsetTFlags.py_type(j) * 4
            x = self._tab.Indirect(x)
            obj = VariableWithValues()
            obj.Init(self._tab.Bytes, x)
            return obj
        return None

    # VariablesWithTime
    def VariablesLength(self) -> int:
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(10))
        if o != 0:
            return self._tab.VectorLen(o)
        return 0

    # VariablesWithTime
    def VariablesIsNone(self) -> bool:
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(10))
        return o == 0





from __future__ import annotations

import flatbuffers
import numpy as np

import flatbuffers
import typing

uoffset: typing.TypeAlias = flatbuffers.number_types.UOffsetTFlags.py_type

class Unit(object):
  undefined: int
  celsius: int
  centimetre: int
  cubic_metre_per_cubic_metre: int
  cubic_metre_per_second: int
  degree_direction: int
  dimensionless_integer: int
  dimensionless: int
  european_air_quality_index: int
  fahrenheit: int
  feet: int
  fraction: int
  gdd_celsius: int
  geopotential_metre: int
  grains_per_cubic_metre: int
  gram_per_kilogram: int
  hectopascal: int
  hours: int
  inch: int
  iso8601: int
  joule_per_kilogram: int
  kelvin: int
  kilopascal: int
  kilogram_per_square_metre: int
  kilometres_per_hour: int
  knots: int
  megajoule_per_square_metre: int
  metre_per_second_not_unit_converted: int
  metre_per_second: int
  metre: int
  micrograms_per_cubic_metre: int
  miles_per_hour: int
  millimetre: int
  pascal: int
  per_second: int
  percentage: int
  seconds: int
  unix_time: int
  us_air_quality_index: int
  watt_per_square_metre: int
  wmo_code: int
  parts_per_million: int




from __future__ import annotations

import flatbuffers
import numpy as np

import flatbuffers
import typing
from openmeteo_sdk.Model import Model
from openmeteo_sdk.VariablesWithTime import VariablesWithTime

uoffset: typing.TypeAlias = flatbuffers.number_types.UOffsetTFlags.py_type

class WeatherApiResponse(object):
  @classmethod
  def GetRootAs(cls, buf: bytes, offset: int) -> WeatherApiResponse: ...
  @classmethod
  def GetRootAsWeatherApiResponse(cls, buf: bytes, offset: int) -> WeatherApiResponse: ...
  def Init(self, buf: bytes, pos: int) -> None: ...
  def Latitude(self) -> float: ...
  def Longitude(self) -> float: ...
  def Elevation(self) -> float: ...
  def GenerationTimeMilliseconds(self) -> float: ...
  def LocationId(self) -> int: ...
  def Model(self) -> typing.Literal[Model.undefined, Model.best_match, Model.gfs_seamless, Model.gfs_global, Model.gfs_hrrr, Model.meteofrance_seamless, Model.meteofrance_arpege_seamless, Model.meteofrance_arpege_world, Model.meteofrance_arpege_europe, Model.meteofrance_arome_seamless, Model.meteofrance_arome_france, Model.meteofrance_arome_france_hd, Model.jma_seamless, Model.jma_msm, Model.jms_gsm, Model.jma_gsm, Model.gem_seamless, Model.gem_global, Model.gem_regional, Model.gem_hrdps_continental, Model.icon_seamless, Model.icon_global, Model.icon_eu, Model.icon_d2, Model.ecmwf_ifs04, Model.metno_nordic, Model.era5_seamless, Model.era5, Model.cerra, Model.era5_land, Model.ecmwf_ifs, Model.gwam, Model.ewam, Model.glofas_seamless_v3, Model.glofas_forecast_v3, Model.glofas_consolidated_v3, Model.glofas_seamless_v4, Model.glofas_forecast_v4, Model.glofas_consolidated_v4, Model.gfs025, Model.gfs05, Model.CMCC_CM2_VHR4, Model.FGOALS_f3_H_highresSST, Model.FGOALS_f3_H, Model.HiRAM_SIT_HR, Model.MRI_AGCM3_2_S, Model.EC_Earth3P_HR, Model.MPI_ESM1_2_XR, Model.NICAM16_8S, Model.cams_europe, Model.cams_global, Model.cfsv2, Model.era5_ocean, Model.cma_grapes_global, Model.bom_access_global, Model.bom_access_global_ensemble, Model.arpae_cosmo_seamless, Model.arpae_cosmo_2i, Model.arpae_cosmo_2i_ruc, Model.arpae_cosmo_5m, Model.ecmwf_ifs025, Model.ecmwf_aifs025, Model.gfs013, Model.gfs_graphcast025, Model.ecmwf_wam025, Model.meteofrance_wave, Model.meteofrance_currents, Model.ecmwf_wam025_ensemble, Model.ncep_gfswave025, Model.ncep_gefswave025, Model.knmi_seamless, Model.knmi_harmonie_arome_europe, Model.knmi_harmonie_arome_netherlands, Model.dmi_seamless, Model.dmi_harmonie_arome_europe, Model.metno_seamless, Model.era5_ensemble, Model.ecmwf_ifs_analysis, Model.ecmwf_ifs_long_window, Model.ecmwf_ifs_analysis_long_window, Model.ukmo_global_deterministic_10km, Model.ukmo_uk_deterministic_2km, Model.ukmo_seamless, Model.ncep_gfswave016, Model.ncep_nbm_conus, Model.ukmo_global_ensemble_20km, Model.ecmwf_aifs025_single, Model.jma_jaxa_himawari, Model.eumetsat_sarah3, Model.eumetsat_lsa_saf_msg, Model.eumetsat_lsa_saf_iodc, Model.satellite_radiation_seamless, Model.kma_gdps, Model.kma_ldps, Model.kma_seamless, Model.italia_meteo_arpae_icon_2i]: ...
  def UtcOffsetSeconds(self) -> int: ...
  def Timezone(self) -> str | None: ...
  def TimezoneAbbreviation(self) -> str | None: ...
  def Current(self) -> VariablesWithTime | None: ...
  def Daily(self) -> VariablesWithTime | None: ...
  def Hourly(self) -> VariablesWithTime | None: ...
  def Minutely15(self) -> VariablesWithTime | None: ...
  def SixHourly(self) -> VariablesWithTime | None: ...
def WeatherApiResponseStart(builder: flatbuffers.Builder) -> None: ...
def Start(builder: flatbuffers.Builder) -> None: ...
def WeatherApiResponseAddLatitude(builder: flatbuffers.Builder, latitude: float) -> None: ...
def WeatherApiResponseAddLongitude(builder: flatbuffers.Builder, longitude: float) -> None: ...
def WeatherApiResponseAddElevation(builder: flatbuffers.Builder, elevation: float) -> None: ...
def WeatherApiResponseAddGenerationTimeMilliseconds(builder: flatbuffers.Builder, generationTimeMilliseconds: float) -> None: ...
def WeatherApiResponseAddLocationId(builder: flatbuffers.Builder, locationId: int) -> None: ...
def WeatherApiResponseAddModel(builder: flatbuffers.Builder, model: typing.Literal[Model.undefined, Model.best_match, Model.gfs_seamless, Model.gfs_global, Model.gfs_hrrr, Model.meteofrance_seamless, Model.meteofrance_arpege_seamless, Model.meteofrance_arpege_world, Model.meteofrance_arpege_europe, Model.meteofrance_arome_seamless, Model.meteofrance_arome_france, Model.meteofrance_arome_france_hd, Model.jma_seamless, Model.jma_msm, Model.jms_gsm, Model.jma_gsm, Model.gem_seamless, Model.gem_global, Model.gem_regional, Model.gem_hrdps_continental, Model.icon_seamless, Model.icon_global, Model.icon_eu, Model.icon_d2, Model.ecmwf_ifs04, Model.metno_nordic, Model.era5_seamless, Model.era5, Model.cerra, Model.era5_land, Model.ecmwf_ifs, Model.gwam, Model.ewam, Model.glofas_seamless_v3, Model.glofas_forecast_v3, Model.glofas_consolidated_v3, Model.glofas_seamless_v4, Model.glofas_forecast_v4, Model.glofas_consolidated_v4, Model.gfs025, Model.gfs05, Model.CMCC_CM2_VHR4, Model.FGOALS_f3_H_highresSST, Model.FGOALS_f3_H, Model.HiRAM_SIT_HR, Model.MRI_AGCM3_2_S, Model.EC_Earth3P_HR, Model.MPI_ESM1_2_XR, Model.NICAM16_8S, Model.cams_europe, Model.cams_global, Model.cfsv2, Model.era5_ocean, Model.cma_grapes_global, Model.bom_access_global, Model.bom_access_global_ensemble, Model.arpae_cosmo_seamless, Model.arpae_cosmo_2i, Model.arpae_cosmo_2i_ruc, Model.arpae_cosmo_5m, Model.ecmwf_ifs025, Model.ecmwf_aifs025, Model.gfs013, Model.gfs_graphcast025, Model.ecmwf_wam025, Model.meteofrance_wave, Model.meteofrance_currents, Model.ecmwf_wam025_ensemble, Model.ncep_gfswave025, Model.ncep_gefswave025, Model.knmi_seamless, Model.knmi_harmonie_arome_europe, Model.knmi_harmonie_arome_netherlands, Model.dmi_seamless, Model.dmi_harmonie_arome_europe, Model.metno_seamless, Model.era5_ensemble, Model.ecmwf_ifs_analysis, Model.ecmwf_ifs_long_window, Model.ecmwf_ifs_analysis_long_window, Model.ukmo_global_deterministic_10km, Model.ukmo_uk_deterministic_2km, Model.ukmo_seamless, Model.ncep_gfswave016, Model.ncep_nbm_conus, Model.ukmo_global_ensemble_20km, Model.ecmwf_aifs025_single, Model.jma_jaxa_himawari, Model.eumetsat_sarah3, Model.eumetsat_lsa_saf_msg, Model.eumetsat_lsa_saf_iodc, Model.satellite_radiation_seamless, Model.kma_gdps, Model.kma_ldps, Model.kma_seamless, Model.italia_meteo_arpae_icon_2i]) -> None: ...
def WeatherApiResponseAddUtcOffsetSeconds(builder: flatbuffers.Builder, utcOffsetSeconds: int) -> None: ...
def WeatherApiResponseAddTimezone(builder: flatbuffers.Builder, timezone: uoffset) -> None: ...
def WeatherApiResponseAddTimezoneAbbreviation(builder: flatbuffers.Builder, timezoneAbbreviation: uoffset) -> None: ...
def WeatherApiResponseAddCurrent(builder: flatbuffers.Builder, current: uoffset) -> None: ...
def WeatherApiResponseAddDaily(builder: flatbuffers.Builder, daily: uoffset) -> None: ...
def WeatherApiResponseAddHourly(builder: flatbuffers.Builder, hourly: uoffset) -> None: ...
def WeatherApiResponseAddMinutely15(builder: flatbuffers.Builder, minutely15: uoffset) -> None: ...
def WeatherApiResponseAddSixHourly(builder: flatbuffers.Builder, sixHourly: uoffset) -> None: ...
def WeatherApiResponseEnd(builder: flatbuffers.Builder) -> uoffset: ...
def End(builder: flatbuffers.Builder) -> uoffset: ...




from __future__ import annotations

import flatbuffers
import numpy as np

import flatbuffers
import typing
from openmeteo_sdk.Aggregation import Aggregation
from openmeteo_sdk.Unit import Unit
from openmeteo_sdk.Variable import Variable

uoffset: typing.TypeAlias = flatbuffers.number_types.UOffsetTFlags.py_type

class VariableWithValues(object):
  @classmethod
  def GetRootAs(cls, buf: bytes, offset: int) -> VariableWithValues: ...
  @classmethod
  def GetRootAsVariableWithValues(cls, buf: bytes, offset: int) -> VariableWithValues: ...
  def Init(self, buf: bytes, pos: int) -> None: ...
  def Variable(self) -> typing.Literal[Variable.undefined, Variable.apparent_temperature, Variable.cape, Variable.cloud_cover, Variable.cloud_cover_high, Variable.cloud_cover_low, Variable.cloud_cover_mid, Variable.daylight_duration, Variable.dew_point, Variable.diffuse_radiation, Variable.diffuse_radiation_instant, Variable.direct_normal_irradiance, Variable.direct_normal_irradiance_instant, Variable.direct_radiation, Variable.direct_radiation_instant, Variable.et0_fao_evapotranspiration, Variable.evapotranspiration, Variable.freezing_level_height, Variable.growing_degree_days, Variable.is_day, Variable.latent_heat_flux, Variable.leaf_wetness_probability, Variable.lifted_index, Variable.lightning_potential, Variable.precipitation, Variable.precipitation_hours, Variable.precipitation_probability, Variable.pressure_msl, Variable.rain, Variable.relative_humidity, Variable.runoff, Variable.sensible_heat_flux, Variable.shortwave_radiation, Variable.shortwave_radiation_instant, Variable.showers, Variable.snow_depth, Variable.snow_height, Variable.snowfall, Variable.snowfall_height, Variable.snowfall_water_equivalent, Variable.sunrise, Variable.sunset, Variable.soil_moisture, Variable.soil_moisture_index, Variable.soil_temperature, Variable.surface_pressure, Variable.surface_temperature, Variable.temperature, Variable.terrestrial_radiation, Variable.terrestrial_radiation_instant, Variable.total_column_integrated_water_vapour, Variable.updraft, Variable.uv_index, Variable.uv_index_clear_sky, Variable.vapour_pressure_deficit, Variable.visibility, Variable.weather_code, Variable.wind_direction, Variable.wind_gusts, Variable.wind_speed, Variable.vertical_velocity, Variable.geopotential_height, Variable.wet_bulb_temperature, Variable.river_discharge, Variable.wave_height, Variable.wave_period, Variable.wave_direction, Variable.wind_wave_height, Variable.wind_wave_period, Variable.wind_wave_peak_period, Variable.wind_wave_direction, Variable.swell_wave_height, Variable.swell_wave_period, Variable.swell_wave_peak_period, Variable.swell_wave_direction, Variable.pm10, Variable.pm2p5, Variable.dust, Variable.aerosol_optical_depth, Variable.carbon_monoxide, Variable.nitrogen_dioxide, Variable.ammonia, Variable.ozone, Variable.sulphur_dioxide, Variable.alder_pollen, Variable.birch_pollen, Variable.grass_pollen, Variable.mugwort_pollen, Variable.olive_pollen, Variable.ragweed_pollen, Variable.european_aqi, Variable.european_aqi_pm2p5, Variable.european_aqi_pm10, Variable.european_aqi_nitrogen_dioxide, Variable.european_aqi_ozone, Variable.european_aqi_sulphur_dioxide, Variable.us_aqi, Variable.us_aqi_pm2p5, Variable.us_aqi_pm10, Variable.us_aqi_nitrogen_dioxide, Variable.us_aqi_ozone, Variable.us_aqi_sulphur_dioxide, Variable.us_aqi_carbon_monoxide, Variable.sunshine_duration, Variable.convective_inhibition, Variable.shortwave_radiation_clear_sky, Variable.global_tilted_irradiance, Variable.global_tilted_irradiance_instant, Variable.ocean_current_velocity, Variable.ocean_current_direction, Variable.cloud_base, Variable.cloud_top, Variable.mass_density, Variable.boundary_layer_height, Variable.formaldehyde, Variable.glyoxal, Variable.non_methane_volatile_organic_compounds, Variable.pm10_wildfires, Variable.peroxyacyl_nitrates, Variable.secondary_inorganic_aerosol, Variable.residential_elementary_carbon, Variable.total_elementary_carbon, Variable.pm2_5_total_organic_matter, Variable.sea_salt_aerosol, Variable.nitrogen_monoxide, Variable.thunderstorm_probability, Variable.rain_probability, Variable.freezing_rain_probability, Variable.ice_pellets_probability, Variable.snowfall_probability, Variable.carbon_dioxide, Variable.methane, Variable.sea_level_height_msl, Variable.sea_surface_temperature, Variable.invert_barometer_height, Variable.hail, Variable.albedo, Variable.precipitation_type, Variable.convective_cloud_base, Variable.convective_cloud_top, Variable.snow_depth_water_equivalent, Variable.secondary_swell_wave_height, Variable.secondary_swell_wave_period, Variable.secondary_swell_wave_peak_period, Variable.secondary_swell_wave_direction, Variable.tertiary_swell_wave_height, Variable.tertiary_swell_wave_period, Variable.tertiary_swell_wave_peak_period, Variable.tertiary_swell_wave_direction]: ...
  def Unit(self) -> typing.Literal[Unit.undefined, Unit.celsius, Unit.centimetre, Unit.cubic_metre_per_cubic_metre, Unit.cubic_metre_per_second, Unit.degree_direction, Unit.dimensionless_integer, Unit.dimensionless, Unit.european_air_quality_index, Unit.fahrenheit, Unit.feet, Unit.fraction, Unit.gdd_celsius, Unit.geopotential_metre, Unit.grains_per_cubic_metre, Unit.gram_per_kilogram, Unit.hectopascal, Unit.hours, Unit.inch, Unit.iso8601, Unit.joule_per_kilogram, Unit.kelvin, Unit.kilopascal, Unit.kilogram_per_square_metre, Unit.kilometres_per_hour, Unit.knots, Unit.megajoule_per_square_metre, Unit.metre_per_second_not_unit_converted, Unit.metre_per_second, Unit.metre, Unit.micrograms_per_cubic_metre, Unit.miles_per_hour, Unit.millimetre, Unit.pascal, Unit.per_second, Unit.percentage, Unit.seconds, Unit.unix_time, Unit.us_air_quality_index, Unit.watt_per_square_metre, Unit.wmo_code, Unit.parts_per_million]: ...
  def Value(self) -> float: ...
  def Values(self, i: int) -> typing.List[float]: ...
  def ValuesAsNumpy(self) -> np.ndarray: ...
  def ValuesLength(self) -> int: ...
  def ValuesIsNone(self) -> bool: ...
  def ValuesInt64(self, i: int) -> typing.List[int]: ...
  def ValuesInt64AsNumpy(self) -> np.ndarray: ...
  def ValuesInt64Length(self) -> int: ...
  def ValuesInt64IsNone(self) -> bool: ...
  def Altitude(self) -> int: ...
  def Aggregation(self) -> typing.Literal[Aggregation.none, Aggregation.minimum, Aggregation.maximum, Aggregation.mean, Aggregation.p10, Aggregation.p25, Aggregation.median, Aggregation.p75, Aggregation.p90, Aggregation.dominant, Aggregation.sum, Aggregation.spread]: ...
  def PressureLevel(self) -> int: ...
  def Depth(self) -> int: ...
  def DepthTo(self) -> int: ...
  def EnsembleMember(self) -> int: ...
  def PreviousDay(self) -> int: ...
def VariableWithValuesStart(builder: flatbuffers.Builder) -> None: ...
def Start(builder: flatbuffers.Builder) -> None: ...
def VariableWithValuesAddVariable(builder: flatbuffers.Builder, variable: typing.Literal[Variable.undefined, Variable.apparent_temperature, Variable.cape, Variable.cloud_cover, Variable.cloud_cover_high, Variable.cloud_cover_low, Variable.cloud_cover_mid, Variable.daylight_duration, Variable.dew_point, Variable.diffuse_radiation, Variable.diffuse_radiation_instant, Variable.direct_normal_irradiance, Variable.direct_normal_irradiance_instant, Variable.direct_radiation, Variable.direct_radiation_instant, Variable.et0_fao_evapotranspiration, Variable.evapotranspiration, Variable.freezing_level_height, Variable.growing_degree_days, Variable.is_day, Variable.latent_heat_flux, Variable.leaf_wetness_probability, Variable.lifted_index, Variable.lightning_potential, Variable.precipitation, Variable.precipitation_hours, Variable.precipitation_probability, Variable.pressure_msl, Variable.rain, Variable.relative_humidity, Variable.runoff, Variable.sensible_heat_flux, Variable.shortwave_radiation, Variable.shortwave_radiation_instant, Variable.showers, Variable.snow_depth, Variable.snow_height, Variable.snowfall, Variable.snowfall_height, Variable.snowfall_water_equivalent, Variable.sunrise, Variable.sunset, Variable.soil_moisture, Variable.soil_moisture_index, Variable.soil_temperature, Variable.surface_pressure, Variable.surface_temperature, Variable.temperature, Variable.terrestrial_radiation, Variable.terrestrial_radiation_instant, Variable.total_column_integrated_water_vapour, Variable.updraft, Variable.uv_index, Variable.uv_index_clear_sky, Variable.vapour_pressure_deficit, Variable.visibility, Variable.weather_code, Variable.wind_direction, Variable.wind_gusts, Variable.wind_speed, Variable.vertical_velocity, Variable.geopotential_height, Variable.wet_bulb_temperature, Variable.river_discharge, Variable.wave_height, Variable.wave_period, Variable.wave_direction, Variable.wind_wave_height, Variable.wind_wave_period, Variable.wind_wave_peak_period, Variable.wind_wave_direction, Variable.swell_wave_height, Variable.swell_wave_period, Variable.swell_wave_peak_period, Variable.swell_wave_direction, Variable.pm10, Variable.pm2p5, Variable.dust, Variable.aerosol_optical_depth, Variable.carbon_monoxide, Variable.nitrogen_dioxide, Variable.ammonia, Variable.ozone, Variable.sulphur_dioxide, Variable.alder_pollen, Variable.birch_pollen, Variable.grass_pollen, Variable.mugwort_pollen, Variable.olive_pollen, Variable.ragweed_pollen, Variable.european_aqi, Variable.european_aqi_pm2p5, Variable.european_aqi_pm10, Variable.european_aqi_nitrogen_dioxide, Variable.european_aqi_ozone, Variable.european_aqi_sulphur_dioxide, Variable.us_aqi, Variable.us_aqi_pm2p5, Variable.us_aqi_pm10, Variable.us_aqi_nitrogen_dioxide, Variable.us_aqi_ozone, Variable.us_aqi_sulphur_dioxide, Variable.us_aqi_carbon_monoxide, Variable.sunshine_duration, Variable.convective_inhibition, Variable.shortwave_radiation_clear_sky, Variable.global_tilted_irradiance, Variable.global_tilted_irradiance_instant, Variable.ocean_current_velocity, Variable.ocean_current_direction, Variable.cloud_base, Variable.cloud_top, Variable.mass_density, Variable.boundary_layer_height, Variable.formaldehyde, Variable.glyoxal, Variable.non_methane_volatile_organic_compounds, Variable.pm10_wildfires, Variable.peroxyacyl_nitrates, Variable.secondary_inorganic_aerosol, Variable.residential_elementary_carbon, Variable.total_elementary_carbon, Variable.pm2_5_total_organic_matter, Variable.sea_salt_aerosol, Variable.nitrogen_monoxide, Variable.thunderstorm_probability, Variable.rain_probability, Variable.freezing_rain_probability, Variable.ice_pellets_probability, Variable.snowfall_probability, Variable.carbon_dioxide, Variable.methane, Variable.sea_level_height_msl, Variable.sea_surface_temperature, Variable.invert_barometer_height, Variable.hail, Variable.albedo, Variable.precipitation_type, Variable.convective_cloud_base, Variable.convective_cloud_top, Variable.snow_depth_water_equivalent, Variable.secondary_swell_wave_height, Variable.secondary_swell_wave_period, Variable.secondary_swell_wave_peak_period, Variable.secondary_swell_wave_direction, Variable.tertiary_swell_wave_height, Variable.tertiary_swell_wave_period, Variable.tertiary_swell_wave_peak_period, Variable.tertiary_swell_wave_direction]) -> None: ...
def VariableWithValuesAddUnit(builder: flatbuffers.Builder, unit: typing.Literal[Unit.undefined, Unit.celsius, Unit.centimetre, Unit.cubic_metre_per_cubic_metre, Unit.cubic_metre_per_second, Unit.degree_direction, Unit.dimensionless_integer, Unit.dimensionless, Unit.european_air_quality_index, Unit.fahrenheit, Unit.feet, Unit.fraction, Unit.gdd_celsius, Unit.geopotential_metre, Unit.grains_per_cubic_metre, Unit.gram_per_kilogram, Unit.hectopascal, Unit.hours, Unit.inch, Unit.iso8601, Unit.joule_per_kilogram, Unit.kelvin, Unit.kilopascal, Unit.kilogram_per_square_metre, Unit.kilometres_per_hour, Unit.knots, Unit.megajoule_per_square_metre, Unit.metre_per_second_not_unit_converted, Unit.metre_per_second, Unit.metre, Unit.micrograms_per_cubic_metre, Unit.miles_per_hour, Unit.millimetre, Unit.pascal, Unit.per_second, Unit.percentage, Unit.seconds, Unit.unix_time, Unit.us_air_quality_index, Unit.watt_per_square_metre, Unit.wmo_code, Unit.parts_per_million]) -> None: ...
def VariableWithValuesAddValue(builder: flatbuffers.Builder, value: float) -> None: ...
def VariableWithValuesAddValues(builder: flatbuffers.Builder, values: uoffset) -> None: ...
def VariableWithValuesStartValuesVector(builder: flatbuffers.Builder, num_elems: int) -> uoffset: ...
def StartValuesVector(builder: flatbuffers.Builder, num_elems: int) -> uoffset: ...
def VariableWithValuesAddValuesInt64(builder: flatbuffers.Builder, valuesInt64: uoffset) -> None: ...
def VariableWithValuesStartValuesInt64Vector(builder: flatbuffers.Builder, num_elems: int) -> uoffset: ...
def StartValuesInt64Vector(builder: flatbuffers.Builder, num_elems: int) -> uoffset: ...
def VariableWithValuesAddAltitude(builder: flatbuffers.Builder, altitude: int) -> None: ...
def VariableWithValuesAddAggregation(builder: flatbuffers.Builder, aggregation: typing.Literal[Aggregation.none, Aggregation.minimum, Aggregation.maximum, Aggregation.mean, Aggregation.p10, Aggregation.p25, Aggregation.median, Aggregation.p75, Aggregation.p90, Aggregation.dominant, Aggregation.sum, Aggregation.spread]) -> None: ...
def VariableWithValuesAddPressureLevel(builder: flatbuffers.Builder, pressureLevel: int) -> None: ...
def VariableWithValuesAddDepth(builder: flatbuffers.Builder, depth: int) -> None: ...
def VariableWithValuesAddDepthTo(builder: flatbuffers.Builder, depthTo: int) -> None: ...
def VariableWithValuesAddEnsembleMember(builder: flatbuffers.Builder, ensembleMember: int) -> None: ...
def VariableWithValuesAddPreviousDay(builder: flatbuffers.Builder, previousDay: int) -> None: ...
def VariableWithValuesEnd(builder: flatbuffers.Builder) -> uoffset: ...
def End(builder: flatbuffers.Builder) -> uoffset: ...

